angular
  .module("starter", [
    "ionic",
    "controllers",
    "services",
    "filters",
    "directives",
    "firebase",
    "pascalprecht.translate",
    "ngCordova"
  ])
  .run(function($ionicPlatform, $rootScope, $state, $cordovaStatusbar) {
    $ionicPlatform.ready(function() {
      if (window.cordova && window.cordova.plugins.Keyboard) {
        cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
        cordova.plugins.Keyboard.disableScroll(true);
      }
      $cordovaStatusbar.style(3);
    });

    $rootScope.$on("$stateChangeError", function(
      event,
      toState,
      toParams,
      fromState,
      fromParams,
      error
    ) {
      if (error === "AUTH_REQUIRED") {
        $state.go("app.signup");
      }
    });
  })
  .config(function(
    $stateProvider,
    $urlRouterProvider,
    $translateProvider,
    $ionicConfigProvider
  ) {
    $ionicConfigProvider.views.maxCache(0);

    $stateProvider
      .state("app", {
        url: "",
        abstract: true,
        templateUrl: "templates/menu.html",
        controller: "AppCtrl"
      })
      .state("app.home", {
        url: "/home",
        views: {
          menuContent: {
            templateUrl: "templates/home.html",
            controller: "HomeCtrl"
          }
        }
      })
      .state("app.login", {
        url: "/login",
        views: {
          menuContent: {
            templateUrl: "templates/login.html",
            controller: "LoginCtrl"
          }
        }
      })
      .state("app.signup", {
        url: "/signup",
        views: {
          menuContent: {
            templateUrl: "templates/signup.html",
            controller: "SignupCtrl"
          }
        }
      })
      .state("app.resetPassword", {
        url: "/reset-password",
        views: {
          menuContent: {
            templateUrl: "templates/reset-password.html",
            controller: "ResetPasswordCtrl"
          }
        }
      })
      .state("app.ranking", {
        url: "/ranking",
        views: {
          menuContent: {
            templateUrl: "templates/ranking.html",
            controller: "RankingCtrl"
          }
        }
      })
      .state("app.mydida", {
        url: "/mydida",
        views: {
          menuContent: {
            templateUrl: "templates/mydida/index.html",
            controller: "MyDiDaCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.myGameRooms", {
        url: "/my-game-rooms",
        views: {
          menuContent: {
            templateUrl: "templates/mydida/my-game-rooms.html",
            controller: "MyGameRoomsCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.myFriends", {
        url: "/my-friends",
        views: {
          menuContent: {
            templateUrl: "templates/mydida/my-friends.html",
            controller: "MyFriendsCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.showFriendship", {
        url: "/friendship/:id",
        views: {
          menuContent: {
            templateUrl: "templates/mydida/friendship.html",
            controller: "FriendshipCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.settings", {
        url: "/settings",
        views: {
          menuContent: {
            templateUrl: "templates/settings/index.html",
            controller: "SettingsCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.myLanguages", {
        url: "/settings/my-languages",
        views: {
          menuContent: {
            templateUrl: "templates/settings/my-languages.html",
            controller: "SettingsMyLanguagesCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.changeUsername", {
        url: "/settings/change-username",
        views: {
          menuContent: {
            templateUrl: "templates/settings/change-username.html",
            controller: "SettingsChangeUsernameCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.changeEmail", {
        url: "/settings/change-email",
        views: {
          menuContent: {
            templateUrl: "templates/settings/change-email.html",
            controller: "SettingsChangeEmailCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.changePassword", {
        url: "/settings/change-password",
        views: {
          menuContent: {
            templateUrl: "templates/settings/change-password.html",
            controller: "SettingsChangePasswordCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.createGame", {
        url: "/game/create",
        views: {
          menuContent: {
            templateUrl: "templates/game/create.html",
            controller: "GameCreateCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.listGames", {
        url: "/game/list",
        views: {
          menuContent: {
            templateUrl: "templates/game/list.html",
            controller: "GameListCtrl"
          }
        }
      })
      .state("app.showGame", {
        url: "/game/:id",
        views: {
          menuContent: {
            templateUrl: "templates/game/show.html",
            controller: "GameShowCtrl"
          }
        }
      })
      .state("app.onlinePlayers", {
        url: "/online-players",
        views: {
          menuContent: {
            templateUrl: "templates/online-players.html",
            controller: "OnlinePlayersCtrl"
          }
        }
      })
      .state("app.cards", {
        url: "/cards",
        views: {
          menuContent: {
            templateUrl: "templates/cards.html",
            controller: "CardsCtrl"
          }
        }
      })
      .state("app.howToPlay", {
        url: "/how-to-play",
        views: {
          menuContent: {
            templateUrl: "templates/how-to-play.html",
            controller: "HowToPlayCtrl"
          }
        }
      })
      .state("app.about", {
        url: "/about",
        views: {
          menuContent: {
            templateUrl: "templates/about.html",
            controller: "AboutCtrl"
          }
        }
      })
      .state("app.privacyPolicy", {
        url: "/privacy-policy",
        views: {
          menuContent: {
            templateUrl: "templates/privacy-policy.html"
          }
        }
      })
      .state("app.credits", {
        url: "/credits",
        views: {
          menuContent: {
            templateUrl: "templates/credits.html",
            controller: "CreditsCtrl"
          }
        }
      })
      .state("app.users", {
        url: "/anni/users",
        views: {
          menuContent: {
            templateUrl: "templates/anni/users.html",
            controller: "UsersCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.feedbacks", {
        url: "/anni/feedbacks",
        views: {
          menuContent: {
            templateUrl: "templates/anni/feedbacks.html",
            controller: "FeedbacksCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      })
      .state("app.contributions", {
        url: "/anni/contributions",
        views: {
          menuContent: {
            templateUrl: "templates/anni/contributions.html",
            controller: "ContributionsCtrl"
          }
        },
        resolve: {
          currentAuth: function(Auth) {
            return Auth.$requireAuth();
          }
        }
      });

    // if none of the above states are matched, use this as the fallback
    $urlRouterProvider.otherwise("/home");

    $translateProvider.translations("English", {
      home: "Home",
      menu: "Menu",
      introductions:
        "DiDa is a fun online card game to play with your families and friends. You can play DiDa on both app and website.",
      chooseLanguage: "Choose language",
      createGameRoom: "Create game room",
      gameRoomList: "Game rooms",
      howToPlay: "How to play",
      viewCards: "View cards",
      myDiDa: "My DiDa",
      settings: "Settings",
      feedback: "Feedback",
      roomName: "Room name",
      storyLanguage: "Story language",
      tips: "Tips",
      tips1:
        "You will be the manager of this game room. You can start the game as long as there are 2 players have joined.",
      tips2:
        "For the game room that only has 2 to 5 players, there will be random cards mixed in each round. So that there are always 6 cards for voting, which will make the game more fun :)",
      login: "Log in",
      email: "Email",
      password: "Password",
      doNotHaveAccount: "Don't have an account?",
      alreadyHaveAccount: "Already have an account?",
      forgotPassword: "Forgot password?",
      signup: "Sign up",
      resetPassword: "Reset password",
      username: "Name",
      totalScore: "Total score",
      gamesWon: "Games won",
      gamesPlayed: "Games played",
      haveNotJoinGameRoom: "You haven't joined any game rooms yet",
      joinOne: "Join one",
      createOne: "Create one",
      message: "Message",
      send: "Send",
      changeUsername: "Change name",
      changeEmail: "Change Email",
      changePassword: "Change password",
      logout: "Log out",
      oldEmail: "Old Email",
      newEmail: "New Email",
      save: "Save",
      oldPassword: "Old password",
      newPassword: "New password",
      waitForJoin: "Please wait for the manager to start this game",
      gameOnGoing: "This game is on going",
      othersSubmitting: "Other players are submitting their cards",
      othersVoting: "Other players are voting for cards",
      waitForOthers: "Please wait for other players",
      tellingStory: " is telling a story",
      gameResults: "🎉 Game finished, here're the rankings:",
      startNewGame: "Start a new game",
      players: "Players",
      ready: "READY",
      storyTelling: "STORY-TELLING",
      storyTold: "STORY-TOLD",
      cardSubmitted: "CARD-SUBMITTED",
      cardVoted: "CARD-VOTED",
      round: "Round",
      storyteller: "Storyteller",
      story: "Story",
      joinGameRoom: "Join this game",
      startGame: "Start this game",
      tellStoryAndSubmitCard: "Please tell a story and submit a cards",
      submit: "Submit",
      submitCardAccordingTo: "Submit one of your cards according to the story",
      sStory: "'s story",
      youSubmitted: "You submitted this card",
      whichOne: "Which one is ",
      sCard: "'s card'",
      vote: "Vote",
      youVoted: "You voted for this card",
      cardsSubmitted: "Cards submitted in this round",
      results: "Results of this round",
      lastResults: "Results of last round",
      owner: "Owner",
      voter: "Voter",
      myCards: "My cards",
      chat: "Chat",
      quitGameRoom: "Quit this game room",
      loginToJoinGame: "Sign up and join this game",
      loginToCreateGame: "Sign up and create game",
      ranking: "Player rankings",
      player: "Player",
      loginWithFacebook: "Continue with Facebook",
      loginWithGoogle: "Continue with Google",
      loginWithEmail: "Log in with Email",
      signupWithEmail: "Sign up with Email",
      oldUsername: "Old name",
      newUsername: "New name",
      pleaseVoteForCard: "Please vote for a card",
      loginFailed: "Login failed",
      pleasePickCard: "Pick a card",
      cannotVoteForOwnCard: "You can not vote for your own card",
      areYouSure: "Are you sure?",
      about: "About",
      new: "NEW",
      started: "ONGOING",
      ended: "ENDED",
      manager: "Manager",
      privateGame: "Private game",
      yes: "Yes",
      cancel: "Cancel",
      waitForManagerStartNewGame:
        "Please wait for the manager to start a new game",
      share: "Share",
      typeStoryHere: "✍️ Type your story here",
      close: "Close",
      randomCard: "Random Card",
      chatRoom: "Chat room",
      privacyPolicy: "Privacy Policy",
      atMostSixPlayers: "At most 6 players",
      addFriend: "Add friend",
      unFriend: "Unfriend",
      sendMessage: "Send message",
      pending: "Pending",
      accept: "Accept",
      friends: "Friends",
      noFriends: "No friends yet",
      lookForFriends: "Look for friends",
      messages: "Messages",
      notifications: "Notifications",
      noNotifications: "No notifications",
      credits: "Credits",
      project: "Project",
      contributor: "Contributor",
      onlinePlayers: "Online players",
      noMessages: "No messages",
      myLanguages: "My languages"
    });

    $translateProvider.translations("中文", {
      home: "首頁",
      menu: "菜單",
      introductions:
        "DiDa是一款有趣的適合和家人朋友一起玩的在線卡片遊戲。你既可以在App上也可以在網站上進行遊戲。",
      chooseLanguage: "選擇語言",
      createGameRoom: "創建遊戲房",
      gameRoomList: "遊戲房",
      howToPlay: "遊戲規則",
      viewCards: "查看卡片",
      myDiDa: "我的DiDa",
      settings: "設置",
      feedback: "回饋",
      roomName: "房間名字",
      storyLanguage: "故事語言",
      tips: "貼士",
      tips1:
        "你將是此遊戲房的管理員，可以在遊戲至少有2位玩家準備好時開始遊戲。",
      tips2:
        "如果遊戲房中只有2至5位玩家，每一輪的卡片中會有隨機卡片混入, 以保證總是有6張卡片候選，讓遊戲更加有趣 :)",
      login: "登錄",
      email: "郵箱",
      password: "密碼",
      doNotHaveAccount: "還沒有賬戶？",
      alreadyHaveAccount: "已經有賬戶了？",
      forgotPassword: "忘記密碼？",
      signup: "註冊",
      resetPassword: "重設密碼",
      username: "名字",
      totalScore: "總積分",
      gamesWon: "獲勝遊戲",
      gamesPlayed: "參與遊戲",
      haveNotJoinGameRoom: "你還沒有加入任何遊戲房",
      joinOne: "加入一個",
      createOne: "創建一個",
      message: "訊息",
      send: "發送",
      changeUsername: "更改名字",
      changeEmail: "更改郵箱",
      changePassword: "更改密碼",
      logout: "登出",
      oldEmail: "舊郵箱",
      newEmail: "新郵箱",
      save: "保存",
      oldPassword: "舊密碼",
      newPassword: "新密碼",
      waitForJoin: "請等待管理員開始遊戲",
      gameOnGoing: "此遊戲正在進行當中",
      othersSubmitting: "其他玩家正在提交他們的卡片",
      othersVoting: "其他玩家正在進行卡片投票",
      waitForOthers: "請等待其他玩家",
      tellingStory: "在講故事",
      gameResults: "🎉 遊戲結束，排名如下:",
      startNewGame: "再來一盤",
      players: "玩家",
      ready: "準備好了",
      storyTelling: "在講故事",
      storyTold: "故事講好了",
      cardSubmitted: "卡片提交了",
      cardVoted: "投票完畢",
      round: "回合",
      storyteller: "講故事的人",
      story: "故事",
      joinGameRoom: "加入此遊戲",
      startGame: "開始遊戲",
      tellStoryAndSubmitCard: "請講一個故事并提交一張卡片",
      submit: "提交",
      submitCardAccordingTo: "請根據故事提交一張卡片",
      sStory: "的故事",
      youSubmitted: "你提交了此卡片",
      whichOne: "哪一張是",
      sCard: "的卡片",
      vote: "投票",
      youVoted: "你投票給了此卡片",
      cardsSubmitted: "本輪大家提交的卡片",
      results: "本輪結果",
      lastResults: "上輪結果",
      owner: "持卡者",
      voter: "投票者",
      myCards: "我的卡片",
      chat: "聊天",
      quitGameRoom: "退出此遊戲房",
      loginToJoinGame: "註冊并加入此遊戲",
      loginToCreateGame: "註冊并創建遊戲",
      ranking: "玩家排行榜",
      player: "玩家",
      loginWithFacebook: "Facebook登錄",
      loginWithGoogle: "Google登錄",
      loginWithEmail: "郵箱登錄",
      signupWithEmail: "郵箱註冊",
      oldUsername: "舊名字",
      newUsername: "新名字",
      pleaseVoteForCard: "請投票给一張卡片",
      loginFailed: "登錄失敗",
      pleasePickCard: "挑選一張卡片",
      cannotVoteForOwnCard: "你不能投票給自己的卡片",
      areYouSure: "你確定嗎？",
      about: "關於",
      new: "新遊戲",
      started: "進行中",
      ended: "結束了",
      manager: "管理員",
      privateGame: "私人遊戲",
      cancel: "取消",
      yes: "確定",
      waitForManagerStartNewGame: "請等待管理員開始新遊戲",
      share: "分享",
      typeStoryHere: "✍️ 把你的故事寫在這裡",
      close: "關閉",
      randomCard: "随机卡",
      chatRoom: "聊天室",
      privacyPolicy: "私密條款",
      atMostSixPlayers: "最多6名玩家",
      addFriend: "添加朋友",
      unFriend: "不做朋友了",
      sendMessage: "發送訊息",
      pending: "等待確認",
      accept: "接受",
      friends: "朋友",
      noFriends: "目前還沒有朋友",
      lookForFriends: "尋覓朋友",
      messages: "訊息",
      notifications: "通知",
      noNotifications: "沒有通知",
      credits: "貢獻者",
      project: "項目",
      contributor: "貢獻者",
      onlinePlayers: "在線玩家",
      noMessages: "沒有訊息",
      myLanguages: "我的語言"
    });

    $translateProvider.translations("Pусский", {
      home: "Главная",
      menu: "Меню",
      introductions:
        "DiDa это веселая карточная игра для для вашей семьи и друзей. Вы можете играть как в приложение так и на сайте.",
      chooseLanguage: "Выбрать язык",
      createGameRoom: "Создать игровую комнату",
      gameRoomList: "Игровые комнаты",
      howToPlay: "Как играть",
      viewCards: "Просмотреть карты",
      myDiDa: "Мой DiDa",
      settings: "Настройки",
      feedback: "Обратная связь",
      roomName: "Комната",
      storyLanguage: "Язык рассказа",
      tips: "Подсказки",
      tips1:
        "Вы будите администратором этой комнаты. Вы можете начать игру как только 2 игрока присоединяться.",
      tips2:
        "В игре с участием от двух до пяти человек, случайные карты будут подмешаны в каждом раунде так чтобы всегда было шесть карт для голосования.",
      login: "Войти",
      email: "E-mail",
      password: "Пароль",
      doNotHaveAccount: "Еще не зарегистрировались?",
      alreadyHaveAccount: "Уже есть аккаунт?",
      forgotPassword: "Забыли пароль?",
      signup: "Регистрация",
      resetPassword: "Сброс пароля",
      username: "Имя",
      totalScore: "Общий счет",
      gamesWon: "Выигранные игры",
      gamesPlayed: "Сыгранные игры",
      haveNotJoinGameRoom:
        "Вы еще не присоединились к какой-либо игровой комнате",
      joinOne: "Присоединиться",
      createOne: "Создать",
      message: "Сообщение",
      send: "Отправить",
      changeUsername: "Сменить имя",
      changeEmail: "Сменить e-mail",
      changePassword: "Изменить пароль",
      logout: "Выйти",
      oldEmail: "Старый e-mail",
      newEmail: "Новый e-mail",
      save: "Сохранить",
      oldPassword: "Старый пароль",
      newPassword: "Новый пароль",
      waitForJoin: "Подождите пока менеджер запустит игру",
      gameOnGoing: "Игра идет",
      othersSubmitting: "Игроки отправляют свои карты",
      othersVoting: "Игроки голосуют за карты",
      waitForOthers: "Подождите других игроков",
      tellingStory: " рассказывает историю",
      gameResults: "🎉 Игра окончена, вот рейтинг:",
      startNewGame: "Начать новую игру",
      players: "Игроки",
      ready: "ГОТОВ",
      storyTelling: "ИСТОРИЯ-РАССКАЗЫВАЕТСЯ",
      storyTold: "ИСТОРИЯ-РАССКАЗАННАЯ",
      cardSubmitted: "КАРТА-ОТПРАВЛЕННАЯ",
      cardVoted: "КАРТА-ПРОГОЛОСОВАННАЯ",
      round: "Раунд",
      storyteller: "Рассказчик",
      story: "История",
      joinGameRoom: "Присоединиться к игре",
      startGame: "Начать игру",
      tellStoryAndSubmitCard: "Расскажите историю и выберите карту",
      submit: "Отправить",
      submitCardAccordingTo: "Выберите одну из ваших карт согласно истории",
      sStory: "рассказ",
      youSubmitted: "Вы выбрали эту карту",
      whichOne: "Какая карта принадлежит ",
      sCard: "",
      vote: "Проголосовать",
      youVoted: "Вы проголосовали за эту карту",
      cardsSubmitted: "Карты представленные в этом раунде",
      results: "Результаты этого раунда",
      lastResults: "Результаты последнего раунда",
      owner: "Хозяин",
      voter: "Участник голосования",
      myCards: "Мои карты",
      chat: "Чат",
      quitGameRoom: "Выйти из этой комнаты",
      loginToJoinGame: "Зарегистрироваться и вступить в игру",
      loginToCreateGame: "Зарегистрироваться и создать игру",
      ranking: "Рейтинги",
      player: "Игрок",
      loginWithFacebook: "Войти с Facebook",
      loginWithGoogle: "Войти с Google",
      loginWithEmail: "Войти по электронной почте",
      signupWithEmail: "Зарегистрироваться по электронной почте",
      oldUsername: "Старое имя",
      newUsername: "Новое имя",
      pleaseVoteForCard: "Проголосуйте за карту",
      loginFailed: "Авторизация не удалась",
      pleasePickCard: "Выберите карту",
      cannotVoteForOwnCard: "Вы не можете голосовать за свою карту",
      areYouSure: "Вы уверены?",
      about: "О игре",
      new: "НОВОЕ",
      started: "СЕЙЧАС ИДЕТ",
      ended: "ЗАКОНЧЕНО",
      manager: "Менеджер",
      privateGame: "Частная игра",
      yes: "Да",
      cancel: "Отмена",
      waitForManagerStartNewGame: "Подождите пока менеджер начнет игру",
      share: "Поделиться",
      typeStoryHere: "✍️ Введите свою историю сюда",
      close: "Закрыть",
      randomCard: "Случайная карта",
      chatRoom: "Чат",
      privacyPolicy: "Условия использования",
      atMostSixPlayers: "Максимум 6 игроков",
      addFriend: "Добавить в друзья",
      unFriend: "Убрать из друзей",
      sendMessage: "Отправить сообщение",
      pending: "В ожидании",
      accept: "Принять",
      friends: "Друзья",
      noFriends: "Пока нет друзей",
      lookForFriends: "Ищите друзей",
      messages: "Сообщения",
      notifications: "Уведомления",
      noNotifications: "Нет уведомлений",
      credits: "Признательность",
      project: "Проект",
      contributor: "Участник",
      onlinePlayers: "Онлайн игроки",
      noMessages: "Нет сообщений",
      myLanguages: "Мои языки"
    });

    $translateProvider.translations("Italiano", {
      home: "Home",
      menu: "Menu",
      introductions:
        "DiDa è un divertente gioco di carte online che si può giocare con parenti e amici. Si può giocare a DiDa sia dall’applicazione sia dal sito web.",
      chooseLanguage: "Scegli la lingua",
      createGameRoom: "Crea una stanza da gioco",
      gameRoomList: "Stanze da gioco",
      howToPlay: "Come si gioca",
      viewCards: "Mostra carte da gioco",
      myDiDa: "Il mio DiDa",
      settings: "Opzioni",
      feedback: "commenti",
      roomName: "Nome della stanza da gioco",
      storyLanguage: "Lingua",
      tips: "Istruzioni",
      tips1:
        "tu sei il manager di questa stanza da gioco. Puoi iniziare la partita dal momento in cui saranno entrati almeno due giocatori.",
      tips2:
        "In ogni stanza da gioco composta da 2 a 5 giocatori saranno scelte casualmente delle carte in ogni turno di gioco. In questo modo ci saranno sempre 6 carte tra cui scegliere così ogni partita sarà divertente",
      login: "Log in",
      email: "Email",
      password: "Password",
      doNotHaveAccount: "Non hai un account?",
      alreadyHaveAccount: "Possiedi già un account?",
      forgotPassword: "Hai dimenticato la password?",
      signup: "Sign up",
      resetPassword: "Resetta la password",
      username: "Nome",
      totalScore: "Punteggio totale",
      gamesWon: "Partite vinte",
      gamesPlayed: "Partite giocate",
      haveNotJoinGameRoom: "non sei ancora entrato in alcuna stanza dagioco",
      joinOne: "entra nella stanza da gioco",
      createOne: "Crea una stanza da gioco",
      message: "Messaggio",
      send: "Invia",
      changeUsername: "Modifica nome",
      changeEmail: "Modifica Email",
      changePassword: "Modifica password",
      logout: "Esci dal gioco",
      oldEmail: "Old Email",
      newEmail: "Nuova Email",
      save: "Salva",
      oldPassword: "Vecchia password",
      newPassword: "Nuova password",
      waitForJoin: "Per favore aspetta che entri il manager della stanza",
      gameOnGoing: "La partita sta per iniziare",
      othersSubmitting: "gli altri giocatori hanno sottoscritto",
      othersVoting: "gli altri giocatori stanno scegliendo la carta",
      waitForOthers: "per favore attendi gli altri giocatori",
      tellingStory: " sta scrivendo una storia",
      gameResults: "🎉 il gioco è finito, questa è la classifica:",
      startNewGame: "inizia una nuova partita",
      players: "Giocatori",
      ready: "PRONTI",
      storyTelling: "NARRAZIONE",
      storyTold: "RACCONTO",
      cardSubmitted: "CARD-SELEZIONATA",
      cardVoted: "CARTA-VOTATA",
      round: "Turno",
      storyteller: "Narratore",
      story: "Racconto",
      joinGameRoom: "Partecipa al gioco",
      startGame: "Inizia la partita",
      tellStoryAndSubmitCard: "Inventa un racconto e scegli una carta",
      submit: "Scegli",
      submitCardAccordingTo:
        "Scegli una delle tue carte che sia inerente al racconto descritta",
      sStory: "'sracconti",
      youSubmitted: "Hai scelto questa carta",
      whichOne: "La carta è questa",
      sCard: "'s carta'",
      vote: "Vota",
      youVoted: "Hai votato questa carta",
      cardsSubmitted: "Carte scelte in questo turno",
      results: "Risultati di questo turno",
      lastResults: "Risultati dell’ultimo turno",
      owner: "Proprietario",
      voter: "Votante",
      myCards: "Le mie carte",
      chat: "Chat",
      quitGameRoom: "Lascia questa stanza da gioco",
      loginToJoinGame: "Entra nel gioco e scegli la stanza da gioco",
      loginToCreateGame: "Entra nel gioco e crea una stanza da gioco",
      ranking: "Classifica dei giocatori",
      player: "Giocatore",
      loginWithFacebook: "Continua con Facebook",
      loginWithGoogle: "Continua con Google",
      loginWithEmail: "Log in con Email",
      signupWithEmail: "Iscriviti con Email",
      oldUsername: "Vecchio nome",
      newUsername: "Nuovo nome",
      pleaseVoteForCard: "Per favore vota una carta",
      loginFailed: "Login fallito",
      pleasePickCard: "Prendi una carta",
      cannotVoteForOwnCard: "Non puoi votare la tua carta",
      areYouSure: "sei sicuro?",
      about: "Riguardo a ",
      new: "NUOVO",
      started: "IN CORSO",
      ended: "FINITO",
      manager: "Manager",
      privateGame: "Partita privata",
      yes: "Si",
      cancel: "Cancella",
      waitForManagerStartNewGame:
        "Attendi il manager della stanza da gioco per iniziare il turno",
      share: "Condividi",
      typeStoryHere: "✍️ Scrivi qui la tua storia",
      close: "Chiudi",
      randomCard: "Carta casuale",
      chatRoom: "Chat room",
      privacyPolicy: "Privacy Policy",
      atMostSixPlayers: "Al massimo 6 giocatori",
      addFriend: "Aggiungi un amico",
      unFriend: "Non amici",
      sendMessage: "Invia un messaggio",
      pending: "In attesa di",
      accept: "Accettare",
      friends: "Amici",
      noFriends: "Nessun amico ancora",
      lookForFriends: "Cerca amici",
      messages: "Messaggi",
      notifications: "Notifiche",
      noNotifications: "Nessuna notifica",
      credits: "Crediti",
      project: "Progetto",
      contributor: "Collaboratori",
      onlinePlayers: "Giocatori online",
      noMessages: "Nessun messaggio",
      myLanguages: "Le mie lingue"
    });

    $translateProvider.translations("Español", {
      home: "Inicio",
      menu: "Menu",
      introductions:
        "DiDa es un divertido juego de mesa online para jugar con familiares y amigos, a través de la app o en la página web.",
      chooseLanguage: "Seleccionar idioma",
      createGameRoom: "Crear sala de juego",
      gameRoomList: "Salas de juego",
      howToPlay: "Como jugar",
      viewCards: "Ver cartas",
      myDiDa: "Mi DiDa",
      settings: "Configuración",
      feedback: "Feedback",
      roomName: "Nombre de la sala",
      storyLanguage: "Idioma de las historias",
      tips: "Trucos",
      tips1:
        "Serás el organizador de la partida. Puedes iniciar el juego, siempre y cuando seáis al menos 2 jugadores.",
      tips2:
        "Para partidas donde haya sólo de 2 a 5 jugadores, habrá cartas aleatorias mezcladas en cada ronda, por lo que siempre hay 6 cartas para votar.",
      login: "Iniciar sesion",
      email: "Email",
      password: "Contraseña",
      doNotHaveAccount: "No tengo usuario",
      alreadyHaveAccount: "Ya tengo usuario",
      forgotPassword: "Olvidé mi contraseña",
      signup: "Darse de alta",
      resetPassword: "Resetear contraseña",
      username: "Nombre",
      totalScore: "Puntuación total",
      gamesWon: "Partidas ganadas",
      gamesPlayed: "Partidas jugadas",
      haveNotJoinGameRoom: "No te has unido a ninguna partida todavía",
      joinOne: "Unete a una partida existente",
      createOne: "Crea una nueva partida",
      message: "Mensaje",
      send: "Enviar",
      changeUsername: "Cambiar nombre",
      changeEmail: "Cambiar Email",
      changePassword: "Cambiar contraseña",
      logout: "Cerrar sesión",
      oldEmail: "Antiguo email",
      newEmail: "Nuevo email",
      save: "Guardar",
      oldPassword: "Antigua contraseña",
      newPassword: "Nueva contraseña",
      waitForJoin:
        "Por favor espera a que el manager dé comienzo a esta partida",
      gameOnGoing: "Esta partida está en curso",
      othersSubmitting: "Otros jugadores están enviando su carta",
      othersVoting: "Otros jugadores están votando",
      waitForOthers: "Por favor espera al resto de jugadores",
      tellingStory: " está narrando una historia",
      gameResults: "🎉 Partida finalizada, aquí estan las puntuaciones:",
      startNewGame: "Comenzar nueva partida",
      players: "Jugadores",
      ready: "ESTOY LISTO",
      storyTelling: "La Historia esta siendo contada",
      storyTold: "La historia ya se ha contado",
      cardSubmitted: "CARTA-ENVIADA",
      cardVoted: "CARTA-VOTADA",
      round: "Ronda",
      storyteller: "Narrador",
      story: "Historia",
      joinGameRoom: "Unete a la partida",
      startGame: "Comienza la partida",
      tellStoryAndSubmitCard: "Por favor cuenta una historia y envia una carta",
      submit: "Enviar carta",
      submitCardAccordingTo:
        "Envía una de las cartas en función de la historia",
      sStory: "'s Historia",
      youSubmitted: "Tu has enviado esta carta",
      whichOne: "Cual es...",
      sCard: "'s Carta'",
      vote: "Votar",
      youVoted: "Votaste por esta carta",
      cardsSubmitted: "Cartas enviadas en esta ronda",
      results: "Resultados de esta ronda",
      lastResults: "Resultados de la ultima ronda",
      owner: "Propietario",
      voter: "Votante",
      myCards: "Mis cartas",
      chat: "Chat",
      quitGameRoom: "Salir de esta partida",
      loginToJoinGame: "Date de alta y unete a esta partida",
      loginToCreateGame: "Date de alta y crea una partida",
      ranking: "Rankings",
      player: "Jugador",
      loginWithFacebook: "Continua con Facebook",
      loginWithGoogle: "Continua con Google",
      loginWithEmail: "Inicia sesión con Email",
      signupWithEmail: "Date de alta con Email",
      oldUsername: "Antiguo nombre",
      newUsername: "Nuevo nombre",
      pleaseVoteForCard: "Por favor vota una carta",
      loginFailed: "Error en el inicio de sesión",
      pleasePickCard: "Escoge una carta",
      cannotVoteForOwnCard: "No puedes votar por tu propia carta",
      areYouSure: "Estás seguro?",
      about: "Acerca de DiDa",
      new: "NUEVO",
      started: "EN CURSO",
      ended: "FINALIZADA",
      manager: "Manager",
      privateGame: "Partida privada",
      yes: "Si",
      cancel: "Cancelar",
      waitForManagerStartNewGame:
        "Por favor espera a que el manager inicie una nueva partida",
      share: "Compartir",
      typeStoryHere: "✍️ Escribe tu historia aquí",
      close: "Cerrar",
      randomCard: "Carta al azar",
      chatRoom: "Sala de Chat",
      privacyPolicy: "Política de privacidad",
      atMostSixPlayers: "Máximo seis jugadores",
      addFriend: "Añadir amigo",
      unFriend: "Cancelar amistad",
      sendMessage: "Enviar mensaje",
      pending: "Pendiente",
      accept: "Aceptar",
      friends: "Amigos",
      noFriends: "No hay amigos todavía",
      lookForFriends: "Busque amigos",
      messages: "Mensajes",
      notifications: "Notificaciones",
      noNotifications: "No Notificaciones",
      credits: "Créditos",
      project: "Proyecto",
      contributor: "Colaborador",
      onlinePlayers: "Jugadores en línea",
      noMessages: "Ningún mensaje",
      myLanguages: "Mis idiomas"
    });

    $translateProvider.translations("Ελληνικά", {
      home: "Αφετηρία",
      menu: "Μενού",
      introductions:
        "Το DiDa είναι ένα διασκεδαστικό online παιχνίδι καρτών για να παίζετε με την οικογένεια και τους φίλους σας. Μπορείτε να παίξετε το DiDa και μέσω της εφαρμογής αλλά και από την ιστοσελίδα.",
      chooseLanguage: "Επιλογή γλώσσας",
      createGameRoom: "Δημιουργία δωματίου",
      gameRoomList: "Δωμάτια παιχνιδιών",
      howToPlay: "Πώς παίζεται",
      viewCards: "Προβολή καρτών",
      myDiDa: "Το DiDa μου",
      settings: "Ρυθμίσεις",
      feedback: "Feedback",
      roomName: "Όνομα δωματίου",
      storyLanguage: "Γλώσσα ιστορίας",
      tips: "Συμβουλές",
      tips1:
        "Θα είστε ο διαχειριστής αυτού του δωματίου παιχνιδιού. Μπορείτε να ξεκινήσετε το παιχνίδι εφ όσον υπάρχουν 2 παίκτες συνδεδεμένοι.",
      tips2:
        "Για το δωμάτιο παιχνιδιού που έχει 2 έως 5 παίκτες, θα υπάρχουν τυχαίες κάρτες αναμεμειγμένες σε κάθε γύρο. Έτσι ώστε να υπάρχουν πάντα 6 κάρτες για ψηφοφορία, που θα κάνουν το παιχνίδι πιο διασκεδαστικό :)",
      login: "Σύνδεση",
      email: "Email",
      password: "Συνθημτικό",
      doNotHaveAccount: "Δημιουργία λογαριασμού",
      alreadyHaveAccount: "Σύνδεση υπάρχοντος λογαριασμού",
      forgotPassword: "Ξεχάσατε το συνθηματικό;",
      signup: "Δημιουργία",
      resetPassword: "Επαναφορά συνθηματικού",
      username: "Όνομα",
      totalScore: "Συνολικοί πόντοι",
      gamesWon: "Νίκες",
      gamesPlayed: "Αριθμός παιχνιδιών",
      haveNotJoinGameRoom:
        "Δεν έχετε συμμετάσχει ακόμα σε κάποιο δωμάτιο παιχνιδιού",
      joinOne: "Σύνδεση σε δωμάτιο",
      createOne: "Δημιουργία δωματίου",
      message: "Μήνυμα",
      send: "Αποστολή",
      changeUsername: "Αλλαγή ονόματος",
      changeEmail: "Αλλαγή Email",
      changePassword: "Αλλαγή συνθηματικού",
      logout: "Αποσύνδεση",
      oldEmail: "Παλιό Email",
      newEmail: "Νέο Email",
      save: "Αποθήκευση",
      oldPassword: "Παλιό συνθηματικό",
      newPassword: "Νέο συνθηματικό",
      waitForJoin: "Περιμένετε να ξεκινήσει αυτό το παιχνίδι ο διαχειριστής",
      gameOnGoing: "Παιχνίδι σε εξέλιξη",
      othersSubmitting: "Οι άλλοι παίκτες υποβάλλουν τις κάρτες τους",
      othersVoting: "Οι άλλοι παίκτες ψηφίζουν τις κάρτες",
      waitForOthers: "Περιμένετε για τους άλλους παίκτες",
      tellingStory: " αφηγείται μία ιστορία",
      gameResults: "🎉 Το παιχνίδι τελείωσε, εδώ είναι η κατάταξη:",
      startNewGame: "Έναρξη νέου παιχνιδιού",
      players: "Παίκτες",
      ready: "Έτοιμο",
      storyTelling: "ΑΦΗΓΗΤΗΣ",
      storyTold: "ΙΣΤΟΡΙΑ",
      cardSubmitted: "ΥΠΟΒΛΗΘΕΙΣΑ ΚΑΡΤΑ",
      cardVoted: "ΨΗΦΙΣΜΕΝΗ ΚΑΡΤΑ",
      round: "Γύρος",
      storyteller: "Αφηγητής",
      story: "Ιστορία",
      joinGameRoom: "Σύνδεση σε αυτό το παιχνίδι",
      startGame: "Έναρξη αυτού του παιχνιδιού",
      tellStoryAndSubmitCard: "Πείτε μια ιστορία και υποβάλετε μια κάρτα",
      submit: "Υποβολή",
      submitCardAccordingTo:
        "Υποβάλετε μία από τις κάρτες σας σύμφωνα με την ιστορία",
      sStory: "Η ιστορία του/της",
      youSubmitted: "Υποβάλατε αυτή την κάρτα",
      whichOne: "Που είναι ",
      sCard: "Η κάρτα του/της ",
      vote: "Ψηφίστε",
      youVoted: "Ψηφίσατε αυτήν την κάρτα",
      cardsSubmitted: "Οι κάρτες που υποβλήθηκαν σε αυτόν τον γύρο",
      results: "Αποτελέσματα γύρου",
      lastResults: "Αποτελέσματα τελευταίου γύρου",
      owner: "Κάτοχος",
      voter: "Ψηφοφόρος",
      myCards: "Οι κάρτες μου",
      chat: "Συνομιλία",
      quitGameRoom: "Αποχώρηση από το δωμάτιο",
      loginToJoinGame: "Εγγραφείτε και συμμετάσχετε σε αυτό το παιχνίδι",
      loginToCreateGame: "Εγγραφείτε και δημιουργήστε ένα παιχνίδι",
      ranking: "Κατάταξη παικτών",
      player: "Παίκτης",
      loginWithFacebook: "Σύνδεση με Facebook",
      loginWithGoogle: "Σύνδεση με Google",
      loginWithEmail: "Σύνδεση με Email",
      signupWithEmail: "Εγγραφλη με Email",
      oldUsername: "Παλιό όνομα",
      newUsername: "Νέο όνομα",
      pleaseVoteForCard: "Ψηφίστε μια κάρτα",
      loginFailed: "Η σύνδεση απέτυχε",
      pleasePickCard: "Επιλέξτε μια κάρτα",
      cannotVoteForOwnCard: "Δεν μπορείτε να ψηφίσετε τη δική σας κάρτα",
      areYouSure: "Επιβεβαίωση",
      about: "ΣΧΕΤΙΚΑ",
      new: "ΝΕΟ",
      started: "ΣΕ ΕΞΕΛΙΞΗ",
      ended: "ΟΛΟΚΛΗΡΩΘΗΚΕ",
      manager: "Διαχειριστής",
      privateGame: "Ιδιωτικό παιχνίδι",
      yes: "Ναι",
      cancel: "Άκυρο",
      waitForManagerStartNewGame:
        "Περιμένετε το διαχειριστή να ξεκινήσει ένα νέο παιχνίδι",
      share: "Κοινή χρήση",
      typeStoryHere: "✍️ Πληκτρολογήστε την ιστορία σας εδώ",
      close: "Κλείσιμο",
      randomCard: "Τυχαία κάρτα",
      chatRoom: "Αίθουσα συζήτησης",
      privacyPolicy: "Πολιτική Απορρήτου",
      atMostSixPlayers: "Έως 6 παίκτες",
      addFriend: "Προσθήκη φίλου",
      unFriend: "Αφαίρεση φίλου",
      sendMessage: "Αποστολή μηνύματος",
      pending: "Σε αναμονή…",
      accept: "Αποδοχή",
      friends: "Φίλοι",
      noFriends: "Δεν υπάρχουν ακόμη φίλοι",
      lookForFriends: "Αναζητήστε για φίλους",
      messages: "Μηνύματα",
      notifications: "Γνωστοποιήσεις",
      noNotifications: "Καμία γνωστοποίηση",
      credits: "Πιστώσεις",
      project: "Εργο",
      contributor: "Συνεισφέρων",
      onlinePlayers: "Συνδεδεμένοι παίκτες",
      noMessages: "Κανένα μήνυμα",
      myLanguages: "Οι γλώσσες μου"
    });

    $translateProvider.translations("日本語", {});

    $translateProvider.translations("한국어", {});

    $translateProvider.preferredLanguage("English");
  });
