angular
  .module("controllers", [])
  .controller("AppCtrl", function(
    $rootScope,
    $scope,
    $ionicPopup,
    $ionicPopover,
    $firebaseObject,
    $firebaseArray,
    LocalStorage,
    $translate,
    $state,
    $ionicHistory,
    $filter,
    Loading,
    $ionicModal
  ) {
    ionic.Platform.fullScreen();

    var language = LocalStorage.get("language");
    if (!language) {
      if (navigator.language.indexOf("zh") == 0) {
        LocalStorage.set("language", "中文");
        language = "中文";
      } else if (navigator.language.indexOf("en") === 0) {
        LocalStorage.set("language", "English");
        language = "English";
      } else if (navigator.language.indexOf("es") === 0) {
        LocalStorage.set("language", "Español");
        language = "Español";
      } else if (navigator.language.indexOf("it") === 0) {
        LocalStorage.set("language", "Italiano");
        language = "Italiano";
      } else if (navigator.language.indexOf("ru") === 0) {
        LocalStorage.set("language", "Pусский");
        language = "Pусский";
      } else if (navigator.language.indexOf("el") === 0) {
        LocalStorage.set("language", "Ελληνικά");
        language = "Ελληνικά";
      }
    }
    $translate.use(language);

    $scope.myTotalNumberOfCards = 226;

    var params = $firebaseObject(
      new Firebase("https://dida.firebaseio.com/params/")
    );
    params.$loaded().then(function() {
      $scope.totalNumberOfCards = params.totalNumberOfCards;
    });

    $scope.getLength = function(object) {
      if (object) {
        return Object.keys(object).length;
      } else {
        return 0;
      }
    };

    $scope.fromNow = function(date) {
      return moment(date).fromNow();
    };

    $scope.toArray = function(data) {
      if (data) {
        return data.split(" ");
      } else {
        return null;
      }
    };

    $scope.cardSource = function(card) {
      if (card > $scope.myTotalNumberOfCards) {
        return "https://www.letsdida.com/img/cards/" + card + ".jpg";
      } else {
        return "./img/cards/" + card + ".jpg";
      }
    };

    $scope.viewCard = function(card) {
      $ionicPopup.alert({
        template:
          '<div class="center"><img src="' +
          $scope.cardSource(card) +
          '" class="full-image"></div>',
        buttons: [
          {
            text: $filter("translate")("close"),
            type: "button-dark"
          }
        ]
      });
    };

    $scope.viewCards = function(firstCard, cards) {
      var index = cards.indexOf(firstCard);
      if (index > -1) {
        cards.splice(index, 1);
        cards.unshift(firstCard);
      }
      $scope.cards = cards;
      $ionicModal
        .fromTemplateUrl("templates/cards-modal.html", { scope: $scope })
        .then(function(modal) {
          $scope.cardsModal = modal;
          $scope.cardsModal.show();
        });
    };

    $scope.closeCards = function() {
      $scope.cardsModal.hide();
    };

    $scope.$on("$destroy", function() {
      $scope.popover.remove();
    });

    $scope.notifyUser = function(userId, game, friendshipId, friendUsername) {
      var notificationId = null;
      if (game) {
        notificationId = game.$id;
      } else if (friendshipId) {
        notificationId = friendshipId;
      }
      var notification = $firebaseObject(
        new Firebase(
          "https://dida.firebaseio.com/users/" +
            userId +
            "/notifications/" +
            notificationId
        )
      );
      notification.$loaded().then(function() {
        if (game) {
          notification.type = "GAME";
          notification.typeId = game.$id;
          notification.typeTitle = game.name;
        } else if (friendshipId) {
          notification.type = "FRIENDSHIP";
          notification.typeId = friendshipId;
          notification.typeTitle = friendUsername;
        }
        notification.createdDate = new Date().getTime();
        notification.$save();
      });
    };

    $scope.sendEmail = function(email, text) {
      var query = {
        apikey: "7fdb6d4e-7e64-4390-a0a2-991fbfae1236",
        subject: text,
        from: "notifications@letsdida.com",
        fromName: "DiDa Game",
        to: email,
        bodyHtml: text,
        bodyText: text,
        isTransactional: "true"
      };
      var fd = new FormData();
      var xhr = new XMLHttpRequest();
      var params = "";
      for (var id in query) {
        var val = query[id] + "";
        params += "&" + encodeURIComponent(id) + "=" + encodeURIComponent(val);
      }
      var queryString = "?" + params.substring(1);
      xhr.open(
        "POST",
        "https://api.elasticemail.com/v2/email/send" + queryString,
        true
      );
      xhr.send(fd);
    };

    $scope.loadUser = function() {
      if (!$scope.user) {
        var authData = new Firebase("https://dida.firebaseio.com").getAuth();
        if (authData) {
          $scope.user = $firebaseObject(
            new Firebase("https://dida.firebaseio.com/users/" + authData.uid)
          );
        }
      }
    };

    $scope.loadUser();

    $scope.updateUserLastActiveTime = function() {
      if ($scope.user) {
        $scope.user.$loaded().then(function() {
          $scope.user.lastActiveTime = new Date().getTime();
          $scope.user.$save();
        });
      }
    };

    $scope.updateUserLastActiveTime();

    window.setInterval($scope.updateUserLastActiveTime, 20000);

    $scope.openPublicProfile = function(userId) {
      $scope.publicProfileUser = $firebaseObject(
        new Firebase("https://dida.firebaseio.com/users/" + userId)
      );
      $scope.publicProfileUser.$loaded().then(function() {
        $ionicModal
          .fromTemplateUrl("templates/public-profile-modal.html", {
            scope: $scope
          })
          .then(function(modal) {
            $scope.showAddFriend = true;
            if ($scope.user) {
              if (userId === $scope.user.$id) {
                $scope.showAddFriend = false;
              } else {
                var friendships = $firebaseArray(
                  new Firebase(
                    "https://dida.firebaseio.com/users/" +
                      $scope.user.$id +
                      "/friendships"
                  )
                    .orderByChild("friendId")
                    .equalTo(userId)
                );
                friendships.$loaded().then(function() {
                  $scope.showAddFriend = friendships.length === 0;
                });
              }
            }
            $scope.success = false;
            $scope.publicProfileModal = modal;
            $scope.publicProfileModal.show();
          });
      });
    };

    $scope.closePublicProfile = function() {
      $scope.publicProfileModal.hide();
    };

    $scope.addFriend = function(recipient, sender) {
      Loading.show();
      if (sender) {
        var createdDate = new Date().getTime();
        var recipientFriendship = $firebaseObject(
          new Firebase(
            "https://dida.firebaseio.com/users/" +
              recipient.$id +
              "/friendships/" +
              createdDate
          )
        );
        recipientFriendship.status = "PENDING";
        recipientFriendship.friendId = sender.$id;
        recipientFriendship.friendUsername = sender.username;
        recipientFriendship.senderId = sender.$id;
        recipientFriendship.createdDate = createdDate;
        recipientFriendship.$save().then(function() {
          var senderFriendship = $firebaseObject(
            new Firebase(
              "https://dida.firebaseio.com/users/" +
                sender.$id +
                "/friendships/" +
                createdDate
            )
          );
          senderFriendship.status = "PENDING";
          senderFriendship.friendId = recipient.$id;
          senderFriendship.friendUsername = recipient.username;
          senderFriendship.senderId = sender.$id;
          senderFriendship.createdDate = createdDate;
          senderFriendship.$save().then(function() {
            $scope.notifyUser(
              recipient.$id,
              null,
              recipientFriendship.$id,
              recipientFriendship.friendUsername
            );
            $scope.success = true;
            $scope.showAddFriend = false;
            if (recipient.email) {
              $scope.sendEmail(
                recipient.email,
                sender.username +
                  ' would like to be your friend. Please review the request in "Friends".'
              );
            }
            Loading.hide();
          });
        });
      } else {
        $scope.publicProfileModal.hide();
        $state.go("app.signup");
        $ionicHistory.nextViewOptions({ disableBack: true });
        Loading.hide();
      }
    };
  })
  .controller("HomeCtrl", function(
    $scope,
    LocalStorage,
    $translate,
    Loading,
    $ionicModal,
    $firebaseArray,
    $firebaseObject,
    $state
  ) {
    Loading.show();
    $scope.isBrowser = !ionic.Platform.isWebView();
    $scope.system = {};
    $scope.languages = [
      "English",
      "Español",
      "Ελληνικά",
      "Italiano",
      "Pусский",
      "中文"
    ];
    var language = LocalStorage.get("language");
    if (language) {
      $scope.system.language = language;
    } else {
      language = "English";
      $scope.system.language = "English";
    }

    $scope.chooseLanguage = function() {
      $translate.use($scope.system.language);
      LocalStorage.set("language", $scope.system.language);
    };

    var authData = new Firebase("https://dida.firebaseio.com").getAuth();

    if (authData) {
      $scope.unReadNotifications = $firebaseArray(
        new Firebase(
          "https://dida.firebaseio.com/users/" + authData.uid + "/notifications"
        )
      );
      $scope.unReadNotifications.$loaded().then(function() {
        Loading.hide();
      });
    } else {
      Loading.hide();
    }

    $scope.openNotifications = function() {
      $ionicModal
        .fromTemplateUrl("templates/notifications-modal.html", {
          scope: $scope
        })
        .then(function(modal) {
          $scope.notificationsModal = modal;
          $scope.notificationsModal.show();
        });
    };

    $scope.closeNotifications = function() {
      $scope.notificationsModal.hide();
    };

    $scope.actOnNotification = function(notification) {
      $scope.closeNotifications();
      if (notification.type === "GAME") {
        $state.go("app.showGame", { id: notification.typeId });
      } else if (notification.type === "FRIENDSHIP") {
        $state.go("app.showFriendship", { id: notification.typeId });
      }
      $scope.unReadNotifications.$remove(notification);
    };
  })
  .controller("HowToPlayCtrl", function($scope, LocalStorage) {
    $scope.language = LocalStorage.get("language");
    if (!$scope.language) {
      $scope.language = "English";
    }
  })
  .controller("LoginCtrl", function(
    $scope,
    $state,
    Loading,
    Auth,
    $ionicHistory,
    LocalStorage,
    $firebaseObject,
    $ionicPopup
  ) {
    $scope.loginWithEmail = function(email, password) {
      Loading.show();
      Auth.$authWithPassword({ email: email, password: password })
        .then(function() {
          LocalStorage.set("email", email);
          $state.go("app.mydida");
          $ionicHistory.nextViewOptions({ disableBack: true });
        })
        .catch(function(error) {
          $scope.error = "Invalid login";
          Loading.hide();
        });
    };
  })
  .controller("SignupCtrl", function(
    $scope,
    $firebaseArray,
    $firebaseObject,
    $state,
    Loading,
    Auth,
    $ionicHistory,
    LocalStorage
  ) {
    $scope.signup = function(username, email, password) {
      Loading.show();
      var usersRef = new Firebase("https://dida.firebaseio.com/users");
      var users = $firebaseArray(
        usersRef.orderByChild("username").equalTo(username)
      );
      users.$loaded().then(function() {
        if (users.length == 0) {
          Auth.$createUser({ email: email, password: password })
            .then(function(userData) {
              var user = $firebaseObject(
                new Firebase(
                  "https://dida.firebaseio.com/users/" + userData.uid
                )
              );
              user.username = username;
              user.email = email;
              user.type = "EMAIL";
              user.numberOfPlayedGames = 0;
              user.numberOfWonGames = 0;
              user.totalScore = 0;
              user.createdDate = new Date().getTime();
              user.$save().then(function() {
                Auth.$authWithPassword({ email: email, password: password })
                  .then(function() {
                    LocalStorage.set("email", email);
                    $state.go("app.mydida");
                    $ionicHistory.nextViewOptions({ disableBack: true });
                  })
                  .catch(function(error) {
                    $scope.error = "Invalid login";
                    Loading.hide();
                  });
              });
            })
            .catch(function(error) {
              switch (error.code) {
                case "INVALID_EMAIL":
                  $scope.error = "Invalid Email";
                  break;
                case "INVALID_PASSWORD":
                  $scope.error = "Invalid password";
                  break;
                case "EMAIL_TAKEN":
                  $scope.error = "This email has been taken";
                  break;
                default:
                  $scope.error = "Something is wrong";
              }
              Loading.hide();
            });
        } else {
          $scope.error = "This username has been taken";
          Loading.hide();
        }
      });
    };

    $scope.loginWithFacebook = function() {
      Loading.show();
      var ref = new Firebase("https://dida.firebaseio.com");
      ref.authWithOAuthPopup(
        "facebook",
        function(error, authData) {
          if (error) {
            Loading.hide();
            $ionicPopup.alert({
              title: $filter("translate")("loginFailed"),
              buttons: [
                {
                  text: "Ok",
                  type: "button-dark"
                }
              ]
            });
          } else {
            var user = $firebaseObject(
              new Firebase("https://dida.firebaseio.com/users/" + authData.uid)
            );
            user.$loaded().then(function() {
              if (user.type) {
                LocalStorage.set("email", user.email);
                $state.go("app.mydida");
                $ionicHistory.nextViewOptions({ disableBack: true });
              } else {
                user.username = authData.facebook.displayName;
                if (!user.username) {
                  user.username = authData.uid;
                }
                user.email = authData.facebook.email;
                user.type = "FACEBOOK";
                user.numberOfPlayedGames = 0;
                user.numberOfWonGames = 0;
                user.totalScore = 0;
                user.createdDate = new Date().getTime();
                user.$save().then(function() {
                  LocalStorage.set("email", user.email);
                  $state.go("app.mydida");
                  $ionicHistory.nextViewOptions({ disableBack: true });
                });
              }
            });
          }
        },
        { scope: "email" }
      );
    };

    $scope.loginWithGoogle = function() {
      Loading.show();
      var ref = new Firebase("https://dida.firebaseio.com");
      ref.authWithOAuthPopup(
        "google",
        function(error, authData) {
          if (error) {
            Loading.hide();
            $ionicPopup.alert({
              title: $filter("translate")("loginFailed"),
              buttons: [
                {
                  text: "Ok",
                  type: "button-dark"
                }
              ]
            });
          } else {
            var user = $firebaseObject(
              new Firebase("https://dida.firebaseio.com/users/" + authData.uid)
            );
            user.$loaded().then(function() {
              if (user.type) {
                LocalStorage.set("email", user.email);
                $state.go("app.mydida");
                $ionicHistory.nextViewOptions({ disableBack: true });
              } else {
                user.username = authData.google.displayName;
                if (!user.username) {
                  user.username = authData.uid;
                }
                user.email = authData.google.email;
                user.type = "GOOGLE";
                user.numberOfPlayedGames = 0;
                user.numberOfWonGames = 0;
                user.totalScore = 0;
                user.createdDate = new Date().getTime();
                user.$save().then(function() {
                  LocalStorage.set("email", user.email);
                  $state.go("app.mydida");
                  $ionicHistory.nextViewOptions({ disableBack: true });
                });
              }
            });
          }
        },
        { scope: "email" }
      );
    };

    $scope.loginWithTwitter = function() {
      Loading.show();
      var ref = new Firebase("https://dida.firebaseio.com");
      ref.authWithOAuthPopup("twitter", function(error, authData) {
        if (error) {
          Loading.hide();
          $ionicPopup.alert({
            title: $filter("translate")("loginFailed"),
            buttons: [
              {
                text: "Ok",
                type: "button-dark"
              }
            ]
          });
        } else {
          var user = $firebaseObject(
            new Firebase("https://dida.firebaseio.com/users/" + authData.uid)
          );
          user.$loaded().then(function() {
            if (user.type) {
              $state.go("app.mydida");
              $ionicHistory.nextViewOptions({ disableBack: true });
            } else {
              user.username = authData.twitter.username;
              if (!user.username) {
                user.username = authData.uid;
              }
              user.type = "TWITTER";
              user.numberOfPlayedGames = 0;
              user.numberOfWonGames = 0;
              user.totalScore = 0;
              user.createdDate = new Date().getTime();
              user.$save().then(function() {
                $state.go("app.mydida");
                $ionicHistory.nextViewOptions({ disableBack: true });
              });
            }
          });
        }
      });
    };
  })
  .controller("ResetPasswordCtrl", function(
    $scope,
    $firebaseObject,
    Auth,
    Loading
  ) {
    $scope.email = "";

    $scope.resetPassword = function(email) {
      Loading.show();
      Auth.$resetPassword({ email: email })
        .then(function() {
          $scope.email = "";
          $scope.success = "Email sent";
          $scope.error = null;
          Loading.hide();
        })
        .catch(function(error) {
          switch (error.code) {
            case "INVALID_EMAIL":
              $scope.error = "Invalid Email";
              break;
            case "INVALID_USER":
              $scope.error = "Invalid user";
              break;
            default:
              $scope.error = "Something is wrong";
          }
          Loading.hide();
        });
    };
  })
  .controller("RankingCtrl", function($scope, $firebaseArray, Loading) {
    Loading.show();
    $scope.users = $firebaseArray(
      new Firebase("https://dida.firebaseio.com/users")
        .orderByChild("totalScore")
        .limit(100)
    );
    $scope.users.$loaded().then(function() {
      Loading.hide();
    });
  })
  .controller("MyDiDaCtrl", function(
    $scope,
    $firebaseObject,
    $ionicHistory,
    LocalStorage,
    $state,
    Auth,
    Loading
  ) {
    $scope.loadUser();
    $scope.user.$loaded().then(function() {
      Loading.hide();
      if (!$scope.user.username) {
        Auth.$unauth();
        LocalStorage.clear();
        $state.go("app.signup");
        $ionicHistory.nextViewOptions({ disableBack: true });
      }
    });
  })
  .controller("MyGameRoomsCtrl", function(
    $scope,
    $firebaseArray,
    Loading,
    $ionicHistory,
    LocalStorage,
    $state,
    Auth
  ) {
    Loading.show();
    $scope.showDelete = false;
    $scope.loadUser();
    $scope.user.$loaded().then(function() {
      if ($scope.user.username) {
        $scope.myGames = $firebaseArray(
          new Firebase(
            "https://dida.firebaseio.com/users/" + $scope.user.$id + "/games"
          )
        );
        $scope.myGames.$loaded().then(function() {
          Loading.hide();
        });
      } else {
        Auth.$unauth();
        LocalStorage.clear();
        Loading.hide();
        $state.go("app.signup");
        $ionicHistory.nextViewOptions({ disableBack: true });
      }
    });

    $scope.toggleShowDelete = function() {
      $scope.showDelete = !$scope.showDelete;
    };

    $scope.delteMyGameRoom = function(game) {
      $scope.myGames.$remove(game);
    };
  })
  .controller("MyFriendsCtrl", function(
    $scope,
    $firebaseArray,
    Loading,
    $ionicHistory,
    LocalStorage,
    $state,
    Auth
  ) {
    Loading.show();
    $scope.loadUser();
    $scope.user.$loaded().then(function() {
      if ($scope.user.username) {
        $scope.myFriendships = $firebaseArray(
          new Firebase(
            "https://dida.firebaseio.com/users/" +
              $scope.user.$id +
              "/friendships"
          )
        );
        $scope.myFriendships.$loaded().then(function() {
          Loading.hide();
        });
      } else {
        Auth.$unauth();
        LocalStorage.clear();
        Loading.hide();
        $state.go("app.signup");
        $ionicHistory.nextViewOptions({ disableBack: true });
      }
    });
  })
  .controller("FriendshipCtrl", function(
    $scope,
    $stateParams,
    $firebaseObject,
    $firebaseArray,
    Loading
  ) {
    Loading.show();
    $scope.loadUser();
    $scope.user.$loaded().then(function() {
      $scope.friendship = $firebaseObject(
        new Firebase(
          "https://dida.firebaseio.com/users/" +
            $scope.user.$id +
            "/friendships/" +
            $stateParams.id
        )
      );
      $scope.friendship.$loaded().then(function() {
        $scope.friend = $firebaseObject(
          new Firebase(
            "https://dida.firebaseio.com/users/" + $scope.friendship.friendId
          )
        );
        $scope.friend.$loaded().then(function() {
          if ($scope.friendship.status === "PENDING") {
            Loading.hide();
          } else if ($scope.friendship.status === "ACCEPTED") {
            $scope.friendMessages = $firebaseArray(
              new Firebase(
                "https://dida.firebaseio.com/friendMessages/" +
                  $scope.friendship.$id
              )
            );
            $scope.friendMessages.$loaded().then(function() {
              Loading.hide();
            });
          }
          $scope.friendship.friendUsername = $scope.friend.username;
          $scope.friendship.$save();
        });
      });
    });

    $scope.acceptFriendship = function(friendshipId, senderId) {
      Loading.show();
      var recipientFriendship = $firebaseObject(
        new Firebase(
          "https://dida.firebaseio.com/users/" +
            $scope.user.$id +
            "/friendships/" +
            friendshipId
        )
      );
      recipientFriendship.$loaded().then(function() {
        if (recipientFriendship.status === "PENDING") {
          recipientFriendship.status = "ACCEPTED";
          recipientFriendship.$save().then(function() {
            var senderFriendship = $firebaseObject(
              new Firebase(
                "https://dida.firebaseio.com/users/" +
                  senderId +
                  "/friendships/" +
                  friendshipId
              )
            );
            senderFriendship.$loaded().then(function() {
              if (senderFriendship.status === "PENDING") {
                senderFriendship.status = "ACCEPTED";
                senderFriendship.$save().then(function() {
                  var sender = $firebaseObject(
                    new Firebase(
                      "https://dida.firebaseio.com/users/" + senderId
                    )
                  );
                  sender.$loaded().then(function() {
                    $scope.notifyUser(
                      sender.$id,
                      null,
                      senderFriendship.$id,
                      senderFriendship.friendUsername
                    );
                    $scope.sendEmail(
                      sender.email,
                      $scope.user.username + " accepted your friend request :)"
                    );
                    Loading.hide();
                  });
                });
              } else {
                Loading.hide();
              }
            });
          });
        } else {
          Loading.hide();
        }
      });
    };

    $scope.sendMessage = function(message) {
      var createdDate = new Date().getTime();
      var friendMessage = $firebaseObject(
        new Firebase(
          "https://dida.firebaseio.com/friendMessages/" +
            $scope.friendship.$id +
            "/" +
            createdDate
        )
      );
      friendMessage.senderId = $scope.user.$id;
      friendMessage.senderName = $scope.user.username;
      friendMessage.createdDate = createdDate;
      friendMessage.content = message.content;
      friendMessage.$save().then(function() {
        message.content = null;
        $scope.notifyUser(
          $scope.friendship.friendId,
          null,
          $scope.friendship.$id,
          $scope.user.username
        );
      });
    };
  })
  .controller("SettingsCtrl", function(
    $scope,
    $state,
    $ionicHistory,
    $ionicPopup,
    LocalStorage,
    Loading,
    $filter,
    Auth
  ) {
    $scope.logout = function() {
      var confirmPopup = $ionicPopup.confirm({
        title: $filter("translate")("areYouSure"),
        buttons: [
          {
            text: $filter("translate")("yes"),
            onTap: function() {
              return true;
            }
          },
          {
            text: $filter("translate")("cancel"),
            type: "button-dark"
          }
        ]
      });

      confirmPopup.then(function(response) {
        if (response) {
          Loading.show();
          Auth.$unauth();
          LocalStorage.clear();
          Loading.hide();
          $state.go("app.home");
          $ionicHistory.nextViewOptions({ disableBack: true });
        }
      });
    };
  })
  .controller("SettingsMyLanguagesCtrl", function($scope, Loading) {
    $scope.save = function() {
      Loading.show();
      $scope.user.$save().then(function() {
        $scope.success = true;
        Loading.hide();
      });
    };
  })
  .controller("SettingsChangeUsernameCtrl", function(
    $scope,
    $firebaseArray,
    Loading
  ) {
    $scope.newUsername = {};

    $scope.changeUsername = function(newUsername) {
      Loading.show();
      var usersRef = new Firebase("https://dida.firebaseio.com/users");
      var users = $firebaseArray(
        usersRef.orderByChild("username").equalTo(newUsername.value)
      );
      users.$loaded().then(function() {
        if (users.length == 0) {
          $scope.user.username = newUsername.value;
          $scope.user.$save().then(function() {
            $scope.newUsername = {};
            $scope.success = "Saved";
            $scope.error = null;
            Loading.hide();
          });
        } else {
          $scope.error = "This username has been taken";
          Loading.hide();
        }
      });
    };
  })
  .controller("SettingsChangeEmailCtrl", function(
    $scope,
    Auth,
    Loading,
    LocalStorage
  ) {
    $scope.newEmail = {};

    $scope.changeEmail = function(newEmail) {
      Loading.show();
      Auth.$changeEmail({
        oldEmail: $scope.user.email,
        newEmail: newEmail.email,
        password: newEmail.password
      })
        .then(function() {
          $scope.user.email = newEmail.email;
          $scope.user.$save().then(function() {
            LocalStorage.set("email", $scope.user.email);
            $scope.newEmail = {};
            $scope.success = "Saved";
            $scope.error = null;
            Loading.hide();
          });
        })
        .catch(function(error) {
          switch (error.code) {
            case "INVALID_EMAIL":
              $scope.error = "Invalid Email";
              break;
            case "INVALID_PASSWORD":
              $scope.error = "Invalid password";
              break;
            case "EMAIL_TAKEN":
              $scope.error = "This email has been taken";
              break;
            default:
              $scope.error = "Something is wrong";
          }
          Loading.hide();
        });
    };
  })
  .controller("SettingsChangePasswordCtrl", function($scope, Auth, Loading) {
    $scope.password = {};

    $scope.changePassword = function(password) {
      Loading.show();
      Auth.$changePassword({
        email: $scope.user.email,
        oldPassword: password.oldPassword,
        newPassword: password.newPassword
      })
        .then(function() {
          $scope.password = {};
          $scope.success = "Saved";
          $scope.error = null;
          Loading.hide();
        })
        .catch(function(error) {
          switch (error.code) {
            case "INVALID_PASSWORD":
              $scope.error = "Invalid old password";
              break;
            default:
              $scope.error = "Something is wrong";
          }
          Loading.hide();
        });
    };
  })
  .controller("GameCreateCtrl", function(
    $scope,
    $firebaseObject,
    $state,
    Loading,
    $ionicHistory
  ) {
    $scope.game = {};
    $scope.game.private = false;
    $scope.loadUser();
    $scope.user.$loaded().then(function() {
      var language = $scope.user.language;
      $scope.game.language =
        language && language.trim().length > 0 ? language : null;
    });

    $scope.create = function(game) {
      Loading.show();
      angular
        .element(document.getElementsByClassName("create-button"))
        .attr("disabled", true);
      $scope.user.language = game.language;
      $scope.user.$save();
      var gameId = new Date().getTime();
      var newGame = $firebaseObject(
        new Firebase("https://dida.firebaseio.com/games/" + gameId)
      );
      newGame.name = game.name;
      newGame.language = game.language;
      newGame.private = game.private;
      if (newGame.private) {
        newGame.password = game.password;
      }
      newGame.status = "NEW";
      var cards = "";
      for (var i = 1; i <= $scope.totalNumberOfCards; i++) {
        cards = cards.concat(i + " ");
      }
      newGame.cards = cards.trim();
      newGame.round = 0;
      newGame.roundStatus = "NEW";
      newGame.roundCards = "";
      newGame.storytellerIndex = 0;
      newGame.createdDate = new Date().getTime();
      newGame.$save().then(function() {
        var myGame = $firebaseObject(
          new Firebase(
            "https://dida.firebaseio.com/users/" +
              $scope.user.$id +
              "/games/" +
              gameId
          )
        );
        myGame.name = game.name;
        myGame.language = game.language;
        myGame.$save();
        var myPlayer = $firebaseObject(
          new Firebase(
            "https://dida.firebaseio.com/games/" +
              gameId +
              "/players/" +
              $scope.user.$id
          )
        );
        myPlayer.name = $scope.user.username;
        myPlayer.email = $scope.user.email;
        myPlayer.platform = $scope.user.platform;
        myPlayer.status = "READY";
        myPlayer.score = 0;
        myPlayer.cards = "";
        myPlayer.story = "";
        myPlayer.answer = "";
        myPlayer.vote = "";
        myPlayer.result = 0;
        myPlayer.lastLoginDate = new Date().getTime();
        // Randomly pick 6 cards and give to myPlayer
        var cardArray = newGame.cards.split(" ");
        var myCards = "";
        for (var i = 0; i < 6; i++) {
          var index = Math.floor(Math.random() * cardArray.length);
          myCards = myCards.concat(cardArray[index] + " ");
          cardArray.splice(index, 1);
        }
        myPlayer.cards = myCards.trim();
        myPlayer.$save().then(function() {
          var game = $firebaseObject(
            new Firebase("https://dida.firebaseio.com/games/" + gameId)
          );
          game.$loaded().then(function() {
            // Set game room manager
            game.manager = $scope.user.$id;
            // Update game card pool
            var gameCards = "";
            cardArray.forEach(function(card) {
              gameCards = gameCards.concat(card + " ");
            });
            game.cards = gameCards.trim();
            game.$save().then(function() {
              Loading.hide();
              $state.go("app.showGame", { id: gameId });
              $ionicHistory.nextViewOptions({ disableBack: true });
            });
          });
        });
      });
    };
  })
  .controller("GameListCtrl", function($scope, $firebaseArray, Loading) {
    Loading.show();
    $scope.games = $firebaseArray(
      new Firebase("https://dida.firebaseio.com/games")
        .orderByChild("createdDate")
        .startAt(new Date().getTime() - 24 * 60 * 60000)
    );
    $scope.games.$loaded().then(function() {
      Loading.hide();
    });
  })
  .controller("GameShowCtrl", function(
    $scope,
    $stateParams,
    $firebaseArray,
    $firebaseObject,
    $ionicPopup,
    $state,
    Loading,
    $ionicScrollDelegate,
    $ionicHistory,
    $filter,
    $ionicPlatform,
    $cordovaNativeAudio,
    $ionicModal,
    $http
  ) {
    if (ionic.Platform.isWebView()) {
      $ionicPlatform.ready(function() {
        $cordovaNativeAudio.preloadSimple("notify", "sounds/notify.mp3");
        $cordovaNativeAudio.preloadSimple("winner", "sounds/winner.mp3");
      });
    }
    $scope.loadUser();
    $scope.game = $firebaseObject(
      new Firebase("https://dida.firebaseio.com/games/" + $stateParams.id)
    );
    $scope.game.$loaded().then(function() {
      $scope.pageTitle = $scope.game.name + " ( " + $scope.game.language + " )";
      var playersRef = new Firebase(
        "https://dida.firebaseio.com/games/" + $scope.game.$id + "/players"
      );
      $scope.players = $firebaseArray(playersRef);
      $scope.rankedPlayers = $firebaseArray(playersRef.orderByChild("score"));
      $scope.players.$loaded().then(function() {
        $scope.user.$loaded().then(function() {
          $scope.myPlayer = $scope.players.$getRecord($scope.user.$id);
          if ($scope.myPlayer) {
            $scope.myPlayer = $firebaseObject(
              new Firebase(
                "https://dida.firebaseio.com/games/" +
                  $scope.game.$id +
                  "/players/" +
                  $scope.user.$id
              )
            );
            $scope.myPlayer.$loaded().then(function() {
              $scope.myPlayer.lastLoginDate = new Date().getTime();
              $scope.myPlayer.$save().then(function() {
                $scope.messages = $firebaseArray(
                  new Firebase(
                    "https://dida.firebaseio.com/games/" +
                      $scope.game.$id +
                      "/messages"
                  )
                );
              });
            });
          } else if ($scope.user.username == "Di") {
            $scope.messages = $firebaseArray(
              new Firebase(
                "https://dida.firebaseio.com/games/" +
                  $scope.game.$id +
                  "/messages"
              )
            );
          }
          if (!ionic.Platform.isWebView()) {
            $scope.user.platform = "Web";
          } else if (ionic.Platform.isIOS()) {
            $scope.user.platform = "iOS";
          } else if (ionic.Platform.isAndroid()) {
            $scope.user.platform = "Android";
          }
          $scope.user.$save();
        });
      });
    });

    $scope.getStoryteller = function() {
      if ($scope.players) {
        return $scope.players.$getRecord($scope.game.storyteller);
      } else {
        return null;
      }
    };

    $scope.getTheOtherPlayer = function() {
      if ($scope.players) {
        switch ($scope.game.storytellerIndex) {
          case 0:
            return $scope.players[1];
          case 1:
            return $scope.players[0];
        }
      } else {
        return null;
      }
    };

    $scope.getWinners = function() {
      var winners = [];
      var maxScore = 0;
      $scope.players.forEach(function(player) {
        if (player.score > maxScore) {
          winners = [];
          winners.push(player.$id);
          maxScore = player.score;
        } else if (player.score == maxScore) {
          winners.push(player.$id);
        }
      });
      return winners;
    };

    $scope.tryToJoinGameRoom = function() {
      if ($scope.players.length < 6) {
        if ($scope.game.private) {
          $scope.data = {};
          var myPopup = $ionicPopup.show({
            template: '<input type="text" ng-model="data.password">',
            title: $filter("translate")("password"),
            scope: $scope,
            buttons: [
              {
                text: $filter("translate")("cancel")
              },
              {
                text: $filter("translate")("login"),
                type: "button-positive",
                onTap: function(e) {
                  if (!$scope.data.password) {
                    e.preventDefault();
                  } else {
                    return $scope.data.password;
                  }
                }
              }
            ]
          });

          myPopup.then(function(password) {
            if (password && $scope.game.password == password) {
              $scope.joinGameRoom();
            } else {
              $ionicPopup.alert({
                title: $filter("translate")("loginFailed"),
                buttons: [
                  {
                    text: "Ok",
                    type: "button-dark"
                  }
                ]
              });
            }
          });
        } else {
          $scope.joinGameRoom();
        }
      } else {
        $ionicPopup.alert({
          title: $filter("translate")("atMostSixPlayers"),
          buttons: [
            {
              text: "Ok",
              type: "button-dark"
            }
          ]
        });
      }
    };

    $scope.joinGameRoom = function() {
      Loading.show();
      var myGame = $firebaseObject(
        new Firebase(
          "https://dida.firebaseio.com/users/" +
            $scope.user.$id +
            "/games/" +
            $scope.game.$id
        )
      );
      myGame.name = $scope.game.name;
      myGame.language = $scope.game.language;
      myGame.$save();
      $scope.myPlayer = $firebaseObject(
        new Firebase(
          "https://dida.firebaseio.com/games/" +
            $scope.game.$id +
            "/players/" +
            $scope.user.$id
        )
      );
      $scope.myPlayer.name = $scope.user.username;
      $scope.myPlayer.email = $scope.user.email;
      $scope.myPlayer.platform = $scope.user.platform;
      $scope.myPlayer.status = "READY";
      $scope.myPlayer.score = 0;
      $scope.myPlayer.cards = "";
      $scope.myPlayer.story = "";
      $scope.myPlayer.answer = "";
      $scope.myPlayer.vote = "";
      $scope.myPlayer.result = 0;
      $scope.myPlayer.lastLoginDate = new Date().getTime();
      // Randomly pick 6 cards and give to myPlayer
      var cardArray = $scope.game.cards.split(" ");
      var myCards = "";
      for (var i = 0; i < 6; i++) {
        var index = Math.floor(Math.random() * cardArray.length);
        myCards = myCards.concat(cardArray[index] + " ");
        cardArray.splice(index, 1);
      }
      $scope.myPlayer.cards = myCards.trim();
      $scope.myPlayer.$save().then(function() {
        // Update game card pool
        var gameCards = "";
        cardArray.forEach(function(card) {
          gameCards = gameCards.concat(card + " ");
        });
        $scope.game.cards = gameCards.trim();
        if ($scope.players.length == 1) {
          $scope.game.manager = $scope.myPlayer.$id;
        }
        $scope.game.createdDate = new Date().getTime();
        $scope.game.$save().then(function() {
          $scope.messages = $firebaseArray(
            new Firebase(
              "https://dida.firebaseio.com/games/" +
                $scope.game.$id +
                "/messages"
            )
          );
          $scope.messages.$loaded().then(function() {
            Loading.hide();
            // Notify manager that someone joined
            if ($scope.myPlayer.$id !== $scope.game.manager) {
              $scope.notifyUser($scope.game.manager, $scope.game, null, null);
            }
          });
        });
      });
    };

    $scope.startGame = function() {
      if ($scope.players.length > 1) {
        Loading.show();
        var winningPoints = 0;
        switch ($scope.players.length) {
          case 6:
            winningPoints = 110;
            break;
          case 5:
            winningPoints = 100;
            break;
          case 4:
            winningPoints = 90;
            break;
          case 3:
            winningPoints = 70;
            break;
          case 2:
            winningPoints = 60;
            break;
        }
        $scope.game.winningPoints = winningPoints;
        $scope.game.status = "STARTED";
        $scope.game.round = 1;
        var storytellerId = $scope.players.$keyAt($scope.game.storytellerIndex);
        var storyteller = $firebaseObject(
          new Firebase(
            "https://dida.firebaseio.com/games/" +
              $scope.game.$id +
              "/players/" +
              storytellerId
          )
        );
        storyteller.$loaded().then(function() {
          storyteller.status = "STORY-TELLING";
          storyteller.$save();
        });
        $scope.game.storyteller = storytellerId;
        $scope.game.createdDate = new Date().getTime();
        $scope.game.$save().then(function() {
          $scope.myPlayer.lastLoginDate = new Date().getTime();
          $scope.myPlayer.$save();
          Loading.hide();
          // Notify other players that game has started
          $scope.players.forEach(function(player) {
            if ($scope.myPlayer.$id !== player.$id) {
              $scope.notifyUser(player.$id, $scope.game, null, null);
              if (player.email) {
                $scope.sendEmail(
                  player.email,
                  'Game "' +
                    $scope.game.name +
                    '" has started. The first storyteller is ' +
                    $scope.getStoryteller().name +
                    "."
                );
              }
            }
          });
        });
      }
    };

    $scope.countCardUsage = function(cardNumber) {
      var cardsRef = new Firebase("https://dida.firebaseio.com/cards");
      var cards = $firebaseArray(
        cardsRef.orderByChild("number").equalTo(cardNumber)
      );
      cards.$loaded().then(function() {
        if (cards.length > 0) {
          var card = cards[0];
          card.count++;
          cards.$save(card);
        } else {
          var card = {
            number: cardNumber,
            count: 1
          };
          cards.$add(card);
        }
      });
    };

    $scope.cardIndexes = [1, 2, 3, 4, 5, 6];

    $scope.story = {};

    $scope.setStoryAnswerCard = function(card) {
      $scope.story.answerCard = card;
    };

    $scope.tellStory = function(story) {
      if (story.answerCard) {
        Loading.show();
        $scope.myPlayer.story = story.text;
        $scope.myPlayer.answer = story.answerCard;
        $scope.myPlayer.status = "STORY-TOLD";
        $scope.myPlayer.lastLoginDate = new Date().getTime();
        $scope.myPlayer.$save().then(function() {
          $scope.game.roundStatus = "STORY-TOLD";
          $scope.game.createdDate = new Date().getTime();
          $scope.game.$save().then(function() {
            $scope.story = {};
            $ionicScrollDelegate.scrollTop();
            Loading.hide();
            // $scope.countCardUsage(parseInt($scope.myPlayer.answer));
            // Notify other players
            $scope.players.forEach(function(player) {
              if ($scope.myPlayer.$id != player.$id) {
                $scope.notifyUser(player.$id, $scope.game, null);
              }
            });
          });
        });
      } else {
        $ionicPopup.alert({
          title: $filter("translate")("pleasePickCard"),
          buttons: [
            {
              text: "Ok",
              type: "button-dark"
            }
          ]
        });
      }
    };

    $scope.submitCard = function(story) {
      if (story.answerCard) {
        Loading.show();
        $scope.myPlayer.answer = story.answerCard;
        $scope.myPlayer.status = "CARD-SUBMITTED";
        $scope.myPlayer.lastLoginDate = new Date().getTime();
        $scope.myPlayer.$save().then(function() {
          var submitCount = 0;
          $scope.players.forEach(function(player) {
            if (player.status == "CARD-SUBMITTED") {
              submitCount++;
            }
          });
          // When everyone has submitted
          if (submitCount == $scope.players.length - 1) {
            $scope.game.roundStatus = "ALL-SUBMITTED";
            var roundCardArray = [];
            $scope.players.forEach(function(player) {
              roundCardArray.push(player.answer);
            });
            // If this game has 2 - 5 players, mix in some random cards to 6 cards
            if ($scope.players.length < 6) {
              var cardArray = $scope.toArray($scope.game.cards);
              while (roundCardArray.length < 6) {
                var index = Math.floor(Math.random() * cardArray.length);
                roundCardArray.push(cardArray[index]);
                cardArray.splice(index, 1);
              }
              var gameCards = "";
              cardArray.forEach(function(card) {
                gameCards = gameCards.concat(card + " ");
              });
              $scope.game.cards = gameCards.trim();
            }
            var roundCards = "";
            for (var i = 0; i < 6; i++) {
              var index = Math.floor(Math.random() * roundCardArray.length);
              roundCards = roundCards.concat(roundCardArray[index] + " ");
              roundCardArray.splice(index, 1);
            }
            $scope.game.roundCards = roundCards.trim();
            $scope.game.createdDate = new Date().getTime();
            $scope.game.$save().then(function() {
              $scope.story = {};
              $ionicScrollDelegate.scrollTop();
              Loading.hide();
            });
          } else {
            $scope.story = {};
            $ionicScrollDelegate.scrollTop();
            Loading.hide();
          }
          // Notify other players
          $scope.players.forEach(function(player) {
            if (
              $scope.myPlayer.$id != player.$id &&
              $scope.game.roundStatus == "ALL-SUBMITTED"
            ) {
              $scope.notifyUser(player.$id, $scope.game, null, null);
            }
          });
          // $scope.countCardUsage(parseInt($scope.myPlayer.answer));
        });
      } else {
        $ionicPopup.alert({
          title: $filter("translate")("pleasePickCard"),
          buttons: [
            {
              text: "Ok",
              type: "button-dark"
            }
          ]
        });
      }
    };

    $scope.vote = {};

    $scope.setVoteCard = function(card) {
      $scope.vote.voteCard = card;
    };

    $scope.voteCard = function(vote) {
      if (vote.voteCard) {
        if (vote.voteCard != $scope.myPlayer.answer) {
          Loading.show();
          $scope.myPlayer.status = "CARD-VOTED";
          $scope.myPlayer.vote = vote.voteCard;
          $scope.myPlayer.lastLoginDate = new Date().getTime();
          $scope.myPlayer.$save().then(function() {
            // Count votes
            var voteCount = 0;
            $scope.players.forEach(function(player) {
              if (player.status == "CARD-VOTED") {
                voteCount++;
              }
            });
            // When everyone has voted
            if (
              ($scope.players.length === 2 &&
                voteCount === $scope.players.length) ||
              ($scope.players.length > 2 &&
                voteCount === $scope.players.length - 1)
            ) {
              var storyteller = $scope.getStoryteller();
              var correctCount = 0;
              $scope.players.forEach(function(player) {
                if (
                  player.$id != storyteller.$id &&
                  player.vote == storyteller.answer
                ) {
                  correctCount++;
                }
              });
              // Calculate results
              if (
                correctCount == $scope.players.length - 1 ||
                correctCount == 0
              ) {
                // If all correct or all wrong
                $scope.players.forEach(function(player) {
                  if (player.$id != storyteller.$id) {
                    player.result = 10;
                    if ($scope.players.length == 2) {
                      if (correctCount == 1) {
                        player.result = 15;
                      } else {
                        player.result = 0;
                      }
                    }
                  } else if ($scope.players.length == 2 && correctCount == 1) {
                    player.result = 10;
                  }
                });
                // Score each vote
                $scope.players.forEach(function(player) {
                  var vote = player.vote;
                  $scope.players.forEach(function(innerPlayer) {
                    if (
                      innerPlayer.$id != storyteller.$id &&
                      innerPlayer.answer == vote
                    ) {
                      innerPlayer.result = innerPlayer.result + 5;
                      if ($scope.players.length == 2) {
                        storyteller.result = storyteller.result + 10;
                      }
                    }
                  });
                });
              } else {
                // If some correct, some wrong
                storyteller.result = 15;
                // Score each vote
                $scope.players.forEach(function(player) {
                  var vote = player.vote;
                  if (vote == storyteller.answer) {
                    player.result = player.result + 15;
                  }
                  $scope.players.forEach(function(innerPlayer) {
                    if (
                      innerPlayer.$id != storyteller.$id &&
                      innerPlayer.answer == vote
                    ) {
                      innerPlayer.result = innerPlayer.result + 5;
                    }
                  });
                });
              }
              // Update game history
              $scope.game.createdDate = new Date().getTime();
              $scope.game.lastStoryteller = storyteller.$id;
              $scope.game.lastStory = storyteller.story;
              $scope.game.lastRoundCards = $scope.game.roundCards;
              // Update players
              var gameCardArray = $scope.toArray($scope.game.cards);
              var winnerCount = 0;
              $scope.players.forEach(function(player) {
                // Update player history
                player.lastAnswer = player.answer;
                player.lastVote = player.vote;
                player.lastResult = player.result;
                player.score = player.score + player.result;
                if (player.score >= $scope.game.winningPoints) {
                  winnerCount++;
                }
                // Take away used card
                var usedCard = player.answer;
                var playerCardArray = $scope.toArray(player.cards);
                var usedCardIndex = playerCardArray.indexOf(usedCard);
                playerCardArray.splice(usedCardIndex, 1);
                var playerCards = "";
                playerCardArray.forEach(function(card) {
                  playerCards = playerCards.concat(card + " ");
                });
                // Get a new one from game card pool
                var playerNewCard = "";
                var index = Math.floor(Math.random() * gameCardArray.length);
                playerNewCard = gameCardArray[index];
                gameCardArray.splice(index, 1);
                playerCards = playerCards.trim().concat(" " + playerNewCard);
                player.cards = playerCards;
                player.status = "READY";
                player.answer = "";
                player.vote = "";
                player.result = 0;
                player.story = "";
              });
              // Update game
              var gameCards = "";
              gameCardArray.forEach(function(card) {
                gameCards = gameCards.concat(card + " ");
              });
              $scope.game.cards = gameCards.trim();
              $scope.game.round++;
              $scope.game.roundStatus = "NEW";
              $scope.game.roundCards = null;
              if ($scope.game.storytellerIndex == $scope.players.length - 1) {
                $scope.game.storytellerIndex = 0;
              } else {
                $scope.game.storytellerIndex++;
              }
              $scope.game.storyteller = $scope.players.$keyAt(
                $scope.game.storytellerIndex
              );
              $scope.game.createdDate = new Date().getTime();
              // If we have winner
              if (winnerCount > 0) {
                $scope.game.status = "ENDED";
              }
              // Save game and players
              $scope.game.$save().then(function() {
                $scope.players.forEach(function(player) {
                  $scope.players.$save(player);
                });
              });
              // Update player total score
              $scope.players.forEach(function(player) {
                var user = $firebaseObject(
                  new Firebase(
                    "https://dida.firebaseio.com/users/" + player.$id
                  )
                );
                user.$loaded().then(function() {
                  user.totalScore = user.totalScore + player.lastResult;
                  // If we have winner
                  if (winnerCount > 0) {
                    user.numberOfPlayedGames++;
                    if ($scope.getWinners().includes(player.$id)) {
                      user.numberOfWonGames++;
                    }
                  }
                  user.$save();
                });
              });
              if (winnerCount === 0) {
                var storyteller = $scope.getStoryteller();
                storyteller.status = "STORY-TELLING";
                $scope.players.$save(storyteller);
              }
              $scope.vote = {};
              $ionicScrollDelegate.scrollTop();
              Loading.hide();
              // Notify other players
              $scope.players.forEach(function(player) {
                if ($scope.myPlayer.$id != player.$id) {
                  $scope.notifyUser(player.$id, $scope.game, null, null);
                }
              });
            } else {
              $scope.vote = {};
              $ionicScrollDelegate.scrollTop();
              Loading.hide();
            }
          });
        } else {
          $ionicPopup.alert({
            title: $filter("translate")("cannotVoteForOwnCard"),
            buttons: [
              {
                text: "Ok",
                type: "button-dark"
              }
            ]
          });
        }
      } else {
        $ionicPopup.alert({
          title: $filter("translate")("pleaseVoteForCard"),
          buttons: [
            {
              text: "Ok",
              type: "button-dark"
            }
          ]
        });
      }
    };

    $scope.startNewGame = function() {
      var confirmPopup = $ionicPopup.confirm({
        title: $filter("translate")("areYouSure"),
        buttons: [
          {
            text: $filter("translate")("yes"),
            onTap: function() {
              return true;
            }
          },
          {
            text: $filter("translate")("cancel"),
            type: "button-dark"
          }
        ]
      });

      confirmPopup.then(function(response) {
        if (response) {
          Loading.show();
          $scope.game.status = "NEW";
          $scope.game.round = 0;
          $scope.game.storytellerIndex = 0;
          var cards = "";
          for (var i = 1; i <= $scope.totalNumberOfCards; i++) {
            cards = cards.concat(i + " ");
          }
          $scope.game.cards = cards.trim();
          $scope.game.roundStatus = "NEW";
          $scope.game.roundCards = "";
          $scope.game.winner = "";
          $scope.game.createdDate = new Date().getTime();
          $scope.game.$save().then(function() {
            var cardArray = $scope.game.cards.split(" ");
            var playerCount = 0;
            $scope.players.forEach(function(player) {
              player.status = "READY";
              player.score = 0;
              player.cards = "";
              player.story = "";
              player.answer = "";
              player.vote = "";
              player.result = 0;
              player.lastLoginDate = new Date().getTime();
              // Randomly pick 6 cards and give to player
              var playerCards = "";
              for (var i = 0; i < 6; i++) {
                var index = Math.floor(Math.random() * cardArray.length);
                playerCards = playerCards.concat(cardArray[index] + " ");
                cardArray.splice(index, 1);
              }
              player.cards = playerCards.trim();
              $scope.players.$save(player).then(function() {
                playerCount++;
                if (playerCount == $scope.players.length) {
                  // Update game card pool
                  var gameCards = "";
                  cardArray.forEach(function(card) {
                    gameCards = gameCards.concat(card + " ");
                  });
                  $scope.game.cards = gameCards.trim();
                  $scope.game.$save();
                }
              });
            });
            Loading.hide();
          });
        }
      });
    };

    $scope.quitGameRoom = function() {
      var confirmPopup = $ionicPopup.confirm({
        title: $filter("translate")("areYouSure"),
        buttons: [
          {
            text: $filter("translate")("yes"),
            onTap: function() {
              return true;
            }
          },
          {
            text: $filter("translate")("cancel"),
            type: "button-dark"
          }
        ]
      });

      confirmPopup.then(function(response) {
        if (response) {
          Loading.show();
          if ($scope.game.status == "NEW") {
            $scope.game.cards = $scope.game.cards.concat(
              " " + $scope.myPlayer.cards
            );
            $scope.game.$save().then(function() {
              var myPlayerId = $scope.myPlayer.$id;
              $scope.myPlayer.$remove().then(function() {
                var myGame = $firebaseObject(
                  new Firebase(
                    "https://dida.firebaseio.com/users/" +
                      $scope.user.$id +
                      "/games/" +
                      $scope.game.$id
                  )
                );
                myGame.$remove().then(function() {
                  if (
                    myPlayerId == $scope.game.manager &&
                    $scope.players.length > 0
                  ) {
                    $scope.game.manager = $scope.players[0].$id;
                    $scope.game.$save();
                  }
                  Loading.hide();
                  $state.go("app.listGames");
                  $ionicHistory.nextViewOptions({ disableBack: true });
                });
              });
            });
          }
        }
      });
    };

    $scope.openChat = function() {
      $ionicModal
        .fromTemplateUrl("templates/chat-modal.html", { scope: $scope })
        .then(function(modal) {
          $scope.chatModal = modal;
          $scope.chatModal.show();
          $scope.unreadMessages = 0;
        });
    };

    $scope.closeChat = function() {
      $scope.unreadMessages = 0;
      $scope.chatModal.hide();
    };

    $scope.message = {};

    $scope.sendMessage = function(message) {
      message.senderId = $scope.user.$id;
      message.senderName = $scope.user.username;
      message.createdDate = new Date().getTime();
      var messages = $firebaseArray(
        new Firebase(
          "https://dida.firebaseio.com/games/" + $scope.game.$id + "/messages"
        )
      );
      messages.$add(message).then(function() {
        $scope.message.content = "";
        $scope.myPlayer.lastLoginDate = new Date().getTime();
        $scope.myPlayer.$save();
      });
    };

    $scope.$watchCollection("messages", function(newValue, oldValue) {
      if (newValue && oldValue && newValue.length > oldValue.length) {
        $scope.unreadMessages = newValue.length - oldValue.length;
      }
    });

    $scope.notify = function() {
      if (
        ionic.Platform.isWebView() &&
        $scope.game.status != "ENDED" &&
        $scope.myPlayer
      ) {
        $cordovaNativeAudio.play("notify");
      }
    };

    $scope.winner = function() {
      if (ionic.Platform.isWebView() && $scope.myPlayer) {
        $cordovaNativeAudio.play("winner");
      }
    };

    $scope.isRandomCard = function(card, players) {
      var isRandomCard = true;
      players.forEach(function(player) {
        if (card == player.lastAnswer) {
          isRandomCard = false;
        }
      });
      return isRandomCard;
    };

    $scope.openLastRoundResults = function() {
      $ionicModal
        .fromTemplateUrl("templates/last-round-results-modal.html", {
          scope: $scope
        })
        .then(function(modal) {
          $scope.lastRoundResultsModal = modal;
          $scope.lastRoundResultsModal.show();
        });
    };

    $scope.closeLastRoundResults = function() {
      $scope.lastRoundResultsModal.hide();
    };

    $scope.$watch("game.roundStatus", function(newValue, oldValue) {
      if (
        newValue &&
        oldValue &&
        oldValue == "ALL-SUBMITTED" &&
        newValue == "NEW"
      ) {
        $scope.openLastRoundResults();
      }
    });
  })
  .controller("CardsCtrl", function($scope) {
    $scope.cards = [];
    for (var i = $scope.totalNumberOfCards; i > 0; i--) {
      $scope.cards.push(i);
    }
  })
  .controller("AboutCtrl", function(
    $scope,
    $http,
    $firebaseArray,
    Loading,
    LocalStorage
  ) {
    $scope.feedback = {};
    $scope.feedback.sender = LocalStorage.get("email");

    $scope.sendFeedback = function(feedback) {
      Loading.show();
      feedback.createdDate = new Date().getTime();
      var feedbacks = $firebaseArray(
        new Firebase("https://dida.firebaseio.com/feedbacks")
      );
      feedbacks.$add(feedback).then(function() {
        $scope.feedback.content = "";
        $scope.success = "Thank you";
        Loading.hide();
      });
    };
  })
  .controller("CreditsCtrl", function(
    $scope,
    $http,
    $firebaseArray,
    Loading,
    $ionicModal,
    LocalStorage
  ) {
    $scope.contribution = {};
    $scope.contribution.sender = LocalStorage.get("email");

    $scope.openContribution = function(project) {
      $scope.contribution.project = project;
      $ionicModal
        .fromTemplateUrl("templates/contribution.html", { scope: $scope })
        .then(function(modal) {
          $scope.contributionModal = modal;
          $scope.contributionModal.show();
        });
    };

    $scope.closeContribution = function() {
      $scope.contributionModal.hide();
    };

    $scope.sendContribution = function(contribution) {
      Loading.show();
      contribution.createdDate = new Date().getTime();
      var contributions = $firebaseArray(
        new Firebase("https://dida.firebaseio.com/contributions")
      );
      contributions.$add(contribution).then(function() {
        $scope.contribution.content = "";
        $scope.success = "Thank you";
        Loading.hide();
      });
    };
  })
  .controller("OnlinePlayersCtrl", function($scope, $firebaseArray, Loading) {
    Loading.show();
    $scope.players = $firebaseArray(
      new Firebase("https://dida.firebaseio.com/users")
        .orderByChild("lastActiveTime")
        .startAt(new Date().getTime() - 60 * 60 * 1000)
    );
    $scope.players.$loaded().then(function() {
      Loading.hide();
    });
  })
  .controller("UsersCtrl", function(
    $scope,
    $firebaseArray,
    $firebaseObject,
    Loading
  ) {
    Loading.show();
    $scope.loadUser();
    $scope.user.$loaded().then(function() {
      if ($scope.user.$id === "5e1b679a-6562-4422-9d3a-51b326ac6272") {
        $scope.users = $firebaseArray(
          new Firebase("https://dida.firebaseio.com/users")
            .orderByChild("createdDate")
            .startAt(new Date().getTime() - 24 * 60 * 60 * 1000)
        );
        $scope.users.$loaded().then(function() {
          Loading.hide();
        });
      }
    });
  })
  .controller("FeedbacksCtrl", function(
    $scope,
    $firebaseArray,
    $firebaseObject,
    Loading
  ) {
    Loading.show();
    $scope.loadUser();
    $scope.user.$loaded().then(function() {
      if ($scope.user.$id === "5e1b679a-6562-4422-9d3a-51b326ac6272") {
        $scope.feedbacks = $firebaseArray(
          new Firebase("https://dida.firebaseio.com/feedbacks").orderByChild(
            "createdDate"
          )
        );
        $scope.feedbacks.$loaded().then(function() {
          Loading.hide();
        });
      }
    });
  })
  .controller("ContributionsCtrl", function(
    $scope,
    $firebaseArray,
    $firebaseObject,
    Loading
  ) {
    Loading.show();
    $scope.loadUser();
    $scope.user.$loaded().then(function() {
      if ($scope.user.$id === "5e1b679a-6562-4422-9d3a-51b326ac6272") {
        $scope.contributions = $firebaseArray(
          new Firebase(
            "https://dida.firebaseio.com/contributions"
          ).orderByChild("createdDate")
        );
        $scope.contributions.$loaded().then(function() {
          Loading.hide();
        });
      }
    });
  });
